




# The R-code for the piecewise linear regression analyses and model selection used to assess capture/tagging and airgun noise-induced movement responses in harbour porpoises


# enter local working directory and load data file on horizontal movements  (available on dryad)
dat <- read.table("...../DRYAD data files/residual_data_horizontal_movements_160503.txt",header=T,sep="\t")
summary(dat)


# load required packages
library(segmented) # for piecewise linear regression (type ?segmented for more info)
library(MuMIn)     # for model selection using AICc 


# subset id1 for analyses 
id1 <- subset(dat,id=="id1")
str(id1)

# step 1) first perform a simple linear regression (on which piecewise regression expands)
o<-lm(residuals_steplength ~ hour_since_release,data= id1)
summary(o)


# step 2) perform piecewise linear regression using using 10 equally spaced starting values (K parameter setting)
set.seed(1)
os<-segmented(o, ~ hour_since_release, psi=NA, K= 10, quant=T ,control =  seg.control(toll=10,n.boot=50, seed=1,random =T)) 

# plot the model with time of airgun exposure (table 1 in article)
dev.new(); plot(os, conf.level=0.95)
abline(v=77,lty=2,col="red")

summary(os) 
slope(os)

# based on the global model os: the only valid breakpoints is at time t = 12.1 (i.e. 95% CI of regression slope does not overlap with 0)  
# step 3) continue with a simpler model using this starting value only (now invoking psi parameter setting)
set.seed(1)
os1<-segmented(o, ~ hour_since_release, psi=c(12.1),control =  seg.control(toll=10,n.boot=50, seed=1,random =T))  

# plot the model with time of airgun exposure
dev.new(); plot(os1, conf.level=0.95)
abline(v=77,lty=2,col="red")

summary(os1) 
slope(os1)

# step 4) to double-check whether additional breakpoints (noise response and recovary) around the time of the airgun exposure are indeed unnecessary we run an additional model with starting values after time t = 77
set.seed(1)
os2<-segmented(o, ~ hour_since_release, psi=c(12.1,77,80,95), control =  seg.control(toll=10,n.boot=50, seed=1,random =T))  

# plot the model with time of airgun exposure
dev.new(); plot(os2, conf.level=0.95)
abline(v=77,lty=2,col="red")

summary(os2) 
slope(os2)

# based on model os2 there is no evidence of airgun behavioural response for this individual in this movement parameter 


## step 5) continue with model selection 
AICc(o,os,os1, os2)

# although models os1 and os2 are equally good in terms of AICc we select model os1 as the final model as its simpler (fewer df).


# step 6) plot the final result using lay-out in article
dev.new(); plot(id1 $hour_since_release, id1$residuals_steplength,ylim=c(-15,20),main="ID 1",xlab="",ylab="",pch=16,col="grey",cex=.85,cex.lab=1.25,las=1,type="p",tck=-0.02,bty="o")
mtext("Step length (m) residuals",2,outer=F ,padj=-3.5,cex=1)
plot(os1,col=c("green", "black"),shade=F,lwd=2,add=T,rug=F) 
lines(os1,col=c("black"),pch=16, bottom=TRUE,lwd=1.25,shift = T, k=13)
legend("topleft",inset=0.025,c("Time of exposure"),lwd=c(1),lty=c(2), col=c("red"),bg="white",box.col="white",cex=0.85)
abline(v=77,lty=2,col="red")

########################################################################

# subset id3 for analyses
id3<- subset(dat,id=="id3")
str(id3)

# step 1) first perform a simple linear regression (on which piecewise regression expands)
o<-lm(residuals_steplength ~ hour_since_release,data= id3)
summary(o)


# step 2) perform piecewise linear regression using using 10 equally spaced starting values (K parameter setting)
set.seed(1)
os<-segmented(o, ~ hour_since_release, psi=NA, K= 10, quant=T ,control =  seg.control(toll=10,n.boot=50, seed=1,random =T)) 

# plot the model with time of airgun exposure (table 1 in article)
dev.new(); plot(os, conf.level=0.95)
abline(v=98,lty=2,col="red")

summary(os) 
slope(os)

# based on the global model os: valid breakpoints are at time t = 22 (i.e. 95% CI of regression slope does not overlap with 0)  
# step 3) continue with a simpler model using this starting value only (now invoking psi parameter setting)
set.seed(1)
os1<-segmented(o, ~ hour_since_release, psi=c(22),control =  seg.control(toll=10,n.boot=50, seed=1,random =T))  

# plot the model with time of airgun exposure
dev.new(); plot(os1, conf.level=0.95)
abline(v=98,lty=2,col="red")

summary(os1) 
slope(os1)

# step 4) to double-check whether additional breakpoints (noise response and recovary) around the time of the airgun exposure are indeed unnecessary we run an additional model with starting values after time t = 98
set.seed(1)
os2<-segmented(o, ~ hour_since_release, psi=c(22, 98,102,115), control =  seg.control(toll=10,n.boot=50, seed=1,random =T))  

# plot the model with time of airgun exposure
dev.new(); plot(os2, conf.level=0.95)
abline(v=98,lty=2,col="red")

summary(os2) 
slope(os2)

# based on model os2 there is evidence of airgun behavioural response for this individual in this movement parameter 

## step 5) continue with model selection 
AICc(o,os,os1, os2)

# model os2 is best in terms of AICc 


# step 6) plot the final result using lay-out in article
dev.new(); plot(id3 $hour_since_release, id3$residuals_steplength,ylim=c(-15,20),main="ID 3",xlab="",ylab="",pch=16,col="grey",cex=.85,cex.lab=1.25,las=1,type="p",tck=-0.02,bty="o")
mtext("Step length (m) residuals",2,outer=F ,padj=-3.5,cex=1)
plot(os2,col=c("green", "black", "red", "blue", "black"),shade=F,lwd=2,add=T,rug=F) 
lines(os2,col=c("black", "red", "blue ", "black"),pch=16, bottom=TRUE,lwd=1.25,shift = T, k=13)
abline(v=98,lty=2,col="red")
legend("topleft",inset=0.025,c("Time of exposure"),lwd=c(1),lty=c(2), col=c("red"),bg="white",box.col="white",cex=0.85)


sessionInfo()
# R version 3.4.1 (2017-06-30)
# Platform: x86_64-apple-darwin15.6.0 (64-bit)
# Running under: macOS Sierra 10.12.6

# Matrix products: default
# BLAS: /Library/Frameworks/R.framework/Versions/3.4/Resources/lib/libRblas.0.dylib
# LAPACK: /Library/Frameworks/R.framework/Versions/3.4/Resources/lib/libRlapack.dylib

# locale:
# [1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8

# attached base packages:
# [1] stats     graphics  grDevices utils     datasets  methods   base     

# other attached packages:
# [1] MuMIn_1.15.6      segmented_0.5-2.1

